@@ -26,9 +26,9 @@
 #'
 #'
 #' @return
-#' If you have just one plot or NULL, there will be just the one of those result. However, if there is multiple plot,
-#' there will be the list with the names of the plot and inside each item their is those results.
-#' Returns a list with if the parameter model is not null:
+#' If plot is NULL or has a single value, a single list is returned. If there is more than one plot,
+#' multiple embedded lists are returned with plots as the list names.
+#' Returns a list if the parameter model is not null:
 #'   - `input`: list of the data used to construct the model (list(H, D))
 #'   - `model`: outputs of the model (same outputs as given by [stats::lm()], [stats::nls()])
 #'   - `RSE`: Residual Standard Error of the model
@@ -42,7 +42,7 @@
 #'
 #'
 #' If the parameter model is null, the function return a graph with all the methods for
-#' comparison, the function also return a data.frame with:
+#' comparison, the function also returns a data.frame with:
 #'   - `method`: The method that had been used to construct the graph
 #'   - `color`: The color of the curve in the graph
 #'   - `RSE`: Residual Standard Error of the model
@@ -62,7 +62,7 @@
 #' data(NouraguesHD)
 #'
 #' # To model the height from a dataset
-#' \dontrun{
+#' \donttest{
 #' HDmodel <- modelHD(D = NouraguesHD$D, H = NouraguesHD$H, drawGraph = TRUE)
 #' }
 #'
@@ -82,6 +82,10 @@
 
 modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, plot = NULL) {
 
+  # # To maintain user's original options
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
+  
   # parameters verification -------------------------------------------------
 
   # Check if there is enough data to compute an accurate model
@@ -128,7 +132,7 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
   if (!is.null(plot) && length(unique(plot)) != 1) {
     Hdata <- data.table(H = H, D = D, plot = plot)
 
-    output <- lapply(split(Hdata, by = "plot", keep.by = T), function(subData) {
+    output <- lapply(split(Hdata, by = "plot", keep.by = TRUE), function(subData) {
       suppressMessages(modelHD(
         subData$D, subData$H, method, useWeight,
         drawGraph, unique(subData$plot)
@@ -200,9 +204,9 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
       pch = 20, cex = 0.5, col = "grey50", log = "xy", las = 1,
       xlab = "D (cm)", ylab = "H (m)", cex.lab = 1.8, cex.axis = 1.5,
       main = main_title,
-      cex.main = 2, axes = F, frame.plot = F
+      cex.main = 2, axes = FALSE, frame.plot = FALSE
     )
-    grid(col = "grey80", lty = 1, equilogs = F)
+    grid(col = "grey80", lty = 1, equilogs = FALSE)
     axis(side = 1, lty = "blank", las = 1)
     axis(side = 2, lty = "blank", las = 1)
   }
@@ -289,7 +293,7 @@ modelHD <- function(D, H, method = NULL, useWeight = FALSE, drawGraph = FALSE, p
       }
 
       return(output)
-    }), fill = T)
+    }), fill = TRUE)
 
     if (is.null(plot)) {
       legend("bottomright", methods,
